<template>
    <div class="userList">
        <header>
            <div class="headerContent">
                <div class="search">
                    <span>筛选条件:</span>
                    <div class="option">
                        <el-select v-model="resource" placeholder="违规" @change="setMystatus">
                            <el-option v-for="item in resourceList" :key="item.label" :label="item.label"
                                :value="item.value">
                            </el-option>
                        </el-select>
                    </div>
                    <div class="findBtn">
                        <el-button type="primary" @click="getUserList">查询</el-button>
                    </div>
                </div>
            </div>
        </header>
        <main>
            <div class="mainContent">
                <div class="type-nav">
                    <div @click="changeTypeChecked(index)" v-for="(item,index) in typeList" :key="item.name"
                        :class="[item.checked ? 'is-active':'','type-item']">{{item.name}}</div>
                </div>
                <!-- 数据展示 -->
                <el-table ref="multipleTable"
                    :header-cell-style="{background:'#06122c','font-size':'12px',color:'#4b9bb7','font-weight':'650','line-height':'45px'}"
                    :data="tableData" style="width: 100%" :row-class-name="tableRowClassName"
                    @selection-change="tableChange">
                    <el-table-column type="selection" min-width="5">
                    </el-table-column>
                    <el-table-column prop="code" label="事件编号" min-width="18">
                        <template slot-scope="scope">
                            <el-link @click="JumpView(scope.row)">{{scope.row.code}}</el-link>
                        </template>
                    </el-table-column>
                    <el-table-column prop="eventSource" label="问题来源" min-width="7">
                        <template slot-scope="scope">
                            <span>{{ scope.row.eventSource === 2 ? '人工上报' : '视频巡查' }}</span>
                        </template>
                    </el-table-column>
                    <el-table-column :prop="mystatus === 1 ? 'category' :'category'"
                        :label="mystatus===1 ? '大类名称' : '违建类别'" :min-width="mystatus===1?'10':'20'">
                    </el-table-column>
                    <el-table-column :prop="mystatus === 1 ? 'type' :'site'" :label="mystatus===1 ? '小类名称' : '违建地点'"
                        min-width="10">
                    </el-table-column>
                    <el-table-column :prop="mystatus === 1 ? 'actionCause' :'communityId'"
                        :label="mystatus===1 ? '案由' : '所属社区'" min-width="10">
                    </el-table-column>
                    <el-table-column :prop="mystatus === 1 ? 'site' :''" :label="mystatus===1 ? '报警点位' : '违法建筑长、宽、高'"
                        :min-width="mystatus===1?'10' :'20' ">
                        <template slot-scope="scope">
                            <div v-if="mystatus ===2"><span>{{scope.row.buildingLength+'米'+'、'+
                            scope.row.buildingWidth+'米'+'、'+scope.row.buildingHigh+'米'}}</span></div>
                            <div v-else>{{scope.row.site}}</div>
                        </template>
                    </el-table-column>
                    <el-table-column :prop="mystatus === 1 ? 'street' :'buildingArea'"
                        :label="mystatus===1 ? '所属区域' : '违法建筑面积'" min-width="10">
                    </el-table-column>
                    <el-table-column prop="alarmTime" label="报警时间" min-width="15" v-if="mystatus===1">
                        <template slot-scope="scope">
                            <span>{{filterTime(scope.row.alarmTime)}}</span>
                        </template>
                    </el-table-column>
                    <el-table-column :prop="mystatus === 1 ? 'continueTime' :'materials'"
                        :label="mystatus===1 ? '持续时间' : '违法建筑材料'" min-width="10">
                    </el-table-column>
                    <el-table-column prop="operation" label="操作" min-width="20">
                        <template slot-scope="scope">
                            <div class="btn">
                                <span @click="handleReset(scope.row)">重新处置</span>
                            </div>
                        </template>
                    </el-table-column>
                </el-table>
                <!-- 详情页展示 -->
                <el-dialog :visible.sync="dialogView" width="60%" title="基础信息(人工)" v-if="dialogView"
                    :before-close="handleClose">
                    <MyDetail :info=info v-if="mystatus === 1"></MyDetail>
                    <MyIllDetail :info=info v-else></MyIllDetail>
                </el-dialog>
                <!-- 上传页面 -->
                <el-dialog :visible.sync="dialogUpload" width="60%" title="上传处置结果" v-if="dialogUpload"
                    :before-close="handleClose">
                    <uploadVio v-if="mystatus === 0" :caseId="caseId" @closeDialog="closeDialog"></uploadVio>
                    <uploadIll v-else :caseId="caseId" @closeDialog="closeDialog"></uploadIll>
                </el-dialog>
                <!-- tools -->
                <div class="tools">
                    <div class="funs">
                        <div class="funsItem funs-sp">
                            <el-checkbox v-model="all" @change="selectAll()">全选</el-checkbox>
                        </div>
                        <div class="funsItem funs-sp">
                            <el-checkbox v-model="unsame" @change="disSame(tableData)">反选</el-checkbox>
                        </div>
                        <!-- <div class="funsItem">
                            <el-select v-model="myIdx" placeholder="批量操作" @change="selectChange" disabled>
                                <el-option v-for="item in options" :key="item.value" :label="item.label"
                                    :value="item.value" :disabled="item.disabled">
                                </el-option>
                            </el-select>
                        </div> -->
                    </div>
                    <div class="pagination">
                        <el-pagination background :current-page="currentPage" layout="prev, pager, next"
                            :total="totalNum" :page-size="pageSize" @current-change="changeCurrentPage"
                            @prev-click="handlePrev" @next-click="handleNext">
                        </el-pagination>
                    </div>
                </div>
            </div>
        </main>
    </div>
</template>
<script>
import uploadVio from './updateUser/uploadResult/vio'
import uploadIll from "./updateUser/uploadResult/ill"
import MyDetail from '@/components/detail'
import MyIllDetail from '@/components/illdetail'
import helper from '@/utils/mydate'
import { RESOURCE_OPTIONS } from "@/utils/helper";
import basecase from "@/api/operate/basecase";

export default {
    components: {
        uploadVio, uploadIll, MyDetail, MyIllDetail
    },
    data() {
        return {
            tableData: [],
            context: "",
            dialogUpload: false,
            dialogView: false,
            info: {},
            totalNum: null,
            pageSize: 10,
            currentPage: 1,
            all: false,
            unsame: false,
            myIdx: 0,
            preMyIdx: 0,
            options: [
                {
                    value: 0,
                    label: '批量操作',
                    disabled: true,
                },
                {
                    value: 1,
                    label: '批量启用',
                },
                {
                    value: 2,
                    label: '批量禁用',
                },
                {
                    value: 3,
                    label: '批量删除',
                }
            ],
            tempList: [],
            typeList: [
                {
                    name: '违规',
                    value: 1,
                    checked: true
                },
                {
                    name: '违建',
                    value: 2,
                    checked: false,
                },
            ],
            statusArr: [],
            mystatus: 1,
            caseId: '',
            resource: null,
            resourceList: RESOURCE_OPTIONS
        }
    },
    created() {
        this.statusArr[0] = 3;
        this.typeList.forEach(item => {
            if (item.checked) {
                this.statusArr[1] = item.value;
            }
        })
        this.getUserList();
    },
    methods: {
        // 顶部下拉框
        setMystatus(value) {
          this.resource = value;
          this.getUserList();
        },
        // 批量删除
        mulDelete(idArr) {
            this.$axios({
                method: 'delete',
                url: 'sccg/violations/batch_delete?ids=' + idArr,
            }).then(res => {
                this.getUserList();
                this.$message({
                    message: res.message,
                    type: res.code === 200 ? 'success' : 'warning'
                })
            })
        },
        // 执行下拉框操作
        selectChange(list) {
            if (this.tempList.length !== 0) {
                if (list === 3) {
                    this.preMyIdx = list;
                    this.mulDelete(this.tempList);
                }
            } else {
                this.myIdx = this.preMyIdx;
                this.$message({
                    type: 'warning',
                    message: '您还没选中任何数据',
                })
            }
        },
        // 监听表格
        tableChange(list) {
            this.tempList = [];
            list.forEach(item => {
                this.tempList.push(item.code);
            })
            this.all = list.length === this.tableData.length;
        },
        // 全选
        selectAll() {
            this.$refs.multipleTable.toggleAllSelection();
        },
        // 反选
        disSame(list) {
            list.forEach(row => {
                this.$refs.multipleTable.toggleRowSelection(row)
            })
        },
        // 删除单条数据
        handleDelete({ number }) {
            this.$confirm('确认删除？')
                .then(_ => {
                    this.$axios({
                        method: 'delete',
                        url: `sccg/violations/delete?id=${number}`,
                    })
                        .then(res => {
                            this.$message({
                                type: res.code === 200 ? 'success' : 'warning',
                                message: res.message
                            })

                            this.getUserList();
                        })
                })
                .catch(_ => { });
        },
        // 获取用户列表
        getUserList() {
          const params = {
            current: this.currentPage,
            state: this.statusArr[0] ?? null,
            size: this.pageSize,
            resource: this.resource,
            type: this.statusArr[1] ?? null
          }
          basecase.baseCasePoolList(params)
              .then(({ records, total }) => {
                this.tableData = records;
                this.totalNum = total;
              })
              .catch(err => this.$message.error(err))
        },
        // 更改违规/违建
        changeTypeChecked(idx) {
            this.typeList.forEach((item, index) => {
                item.checked = index === idx;
            })
            this.mystatus = idx + 1;
            this.statusArr[1] = this.typeList[idx].value;
            this.getUserList();
        },
        // 设置表格斑马纹
        tableRowClassName({ row, rowIndex }) {
            if ((rowIndex + 1) % 2 === 0) {
                return 'warning-row';
            } else {
                return 'success-row';
            }
        },
        // 当前页改变触发事件
        changeCurrentPage(page) {
            this.currentPage = page;
            this.getUserList();
        },
        // 上一页点击事件
        handlePrev(page) {
            this.currentPage = page;
            this.getUserList();
        },
        // 下一页点击事件
        handleNext(page) {
            this.currentPage = page;
            this.getUserList();
        },
        handleClose(done) {
            this.$confirm('确认关闭？')
                .then(_ => {
                    this.dialogUpload = false;
                    // this.dialogUpdate = false;
                    done();
                })
                .catch(_ => { });
        },
        async JumpView(data) {
            await this.getEventInfo(data.code);
        },
        // 获取案件信息
        getEventInfo(code) {
            this.$axios({
                method: 'get',
                url: `sccg/base_case/baseCaseDetail/${code}`
            })
                .then(res => {
                    this.info = res.data;
                    this.dialogView = true;
                })
        },

        // 重新处置
        handleReset({ id }) {
            this.$axios({
                method: 'put',
                url: 'sccg/base_case/case_status_update?caseId=' + id + '&state=0'
            })
                .then(res => {
                    if (res.code === 200) {
                        this.$message({
                            type: 'success',
                            message: '处置成功',
                        })
                        this.getUserList();
                    } else {
                        this.$message({
                            type: 'error',
                            message: '操作失败'
                        })
                    }
                })
        },
        // 关闭上传界面
        closeDialog({ flag }) {
            this.dialogUpload = flag;
        },
        filterTime(time) {
            return helper(time);
        }
    }
}
</script>
<style lang="scss" scoped>
.userList {
    text-align: left;
    margin: 10px 20px;
    color: #4b9bb7;

    header {
        background-color: #09152f;

        .headerContent {
            padding: 0 40px;
            display: flex;
            line-height: 100px;
            justify-content: space-between;
            align-items: center;

            .search {
                display: flex;
                justify-content: flex-start;

                span {
                    flex: 1;
                }

                .el-input {
                    flex: 2;
                    color: #1d3f57;

                    &::v-deep .el-input__inner {
                        background-color: #09152f;
                        border: 1px solid #17324c;
                    }
                }

            }

            .findBtn {
                line-height: 100px;
                margin-left: 15px;
                display: flex;
                align-items: center;
                margin-top: -2px;

                .el-button {
                    padding: 12px 25px;
                    border-radius: 20px;
                }
            }

            .addBtn {
                background-color: #eb5d01;
                border: none;
                border-radius: 20px;
                padding: 12px 30px;
            }
        }
    }

    main {
        background-color: #09152f;
        margin-top: 20px;
        padding-bottom: 50px;

        .btn span:hover {
            cursor: pointer;
        }

        .type-nav {
            display: flex;
            line-height: 40px;
            margin-left: 30px;
            padding-top: 10px;
            margin-bottom: 10px;

            .type-item {
                width: 80px;
                text-align: center;

                &:hover {
                    cursor: pointer;
                }
            }

            .is-active {
                background-color: #070f22;
                border-radius: 4px;
                color: #fff;
            }
        }

        .tools {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 0 20px;

            .funs {
                display: flex;
                .funs-sp{
                    border: 1px solid #17324c;
                }
                .funsItem {
                    line-height: 28px;
                    display: flex;
                    align-items: center;
                    border-radius: 4px;
                    font-size: 12px;
                    margin-left: 10px;

                    .el-checkbox {
                        width: 80px;
                        padding: 0 10px;
                    }

                    .el-select {
                        width: 120px;
                    }

                    &:hover {
                        border: 1px solid #4b9bb7;
                    }

                    &:hover .el-checkbox {
                        color: #4b9bb7;
                    }
                }

            }

            .pagination {
                margin-top: 50px;
                display: flex;
                line-height: 50px;
                justify-content: center;

                .el-pagination {

                    &::v-deep li,
                    &::v-deep .btn-prev,
                    &::v-deep .btn-next {
                        background-color: #071f39;
                        color: #4b9bb7;
                    }

                    &::v-deep .active {
                        background-color: #409eff;
                        color: #fff;
                    }
                }
            }
        }

        .el-table {
            color: #4b9bb7;
            font-size: 10px;

            &::v-deep .cell {
                text-overflow: ellipsis;
                white-space: nowrap;
                overflow: hidden;
            }

            .operation {
                display: flex;

                .line {
                    padding: 0 5px;
                }

                span:hover {
                    cursor: pointer;
                }
            }
        }
    }

    .line {
        padding: 0 5px;
    }
}
</style>